@@ -9,7 +9,6 @@ import os
 import uuid
 
 from django.core.files.storage import default_storage
-from django.utils.decorators import method_decorator
 from django.utils.functional import cached_property
 from django.utils import timezone
 from django.conf import settings
@@ -25,7 +24,11 @@ class S3FineView(View):
     bucket_name = settings.AWS_STORAGE_BUCKET_NAME
     upload_folder_name = os.path.join('tmp', 's3fine')
 
-    @method_decorator(csrf_exempt)
+    @classmethod
+    def as_view(cls, **initkwargs):
+        view = super(S3FineView, cls).as_view(**initkwargs)
+        return csrf_exempt(view)
+
     def post(self, request, *args, **kwargs):
         request_dict = request.DATA
 
@@ -37,7 +40,7 @@ class S3FineView(View):
         self.file_name = request_dict['filename']
         self.mime_type = request_dict['mime_type']
 
-        return HttpResponse(self.sign())
+        return HttpResponse(json.dumps(self.sign()))
 
     def get_expiration_date(self):
         expiration_date = timezone.datetime.utcnow() + self.expires
